Welcome to django_wmd's documentation!
======================================

A wmd-editor for django application

.. image:: https://travis-ci.org/Lispython/django_wmd.png?branch=master
	   :target: https://travis-ci.org/Lispython/django_wmd


INSTALLATION
------------

To use jinja-kit use `pip` or `easy_install`:

``pip install django_wmd``

or

``easy_install django_wmd``


DJANGO USAGE
------------


Added ``wmd`` to your ``INSTALLED_APPS``:

.. code-block:: python

   INSTALLED_APPS += 'wmd',




CONTRIBUTE
----------

Fork https://github.com/lispython/django-wmd/ , create commit and pull request.

